@@ -15,7 +15,7 @@ BEGIN {
     }
 }
 use warnings;
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 use utf8;
 
 # Class for $PPR::X::ERROR objects...
@@ -65,16 +65,22 @@ our $GRAMMAR = qr{
 (?(DEFINE)
 
     (?<PerlDocument>   (?<PerlStdDocument>
-        \x{FEFF}?+      # Optional BOM marker
-        (?>(?&PerlOWS))
-        (?: (?>(?&PerlStatement)) (?&PerlOWS) )*+
+        \x{FEFF}?+                      # Optional BOM marker
+        (?&PerlStatementSequence)?+
+    )) # End of rule
+
+    (?<PerlStatementSequence>   (?<PerlStdStatementSequence>
+        (?&PerlPodSequence)?+
+        (?:
+            (?&PerlStatement)
+            (?&PerlPodSequence)?+
+        )*+
     )) # End of rule
 
     (?<PerlStatement>   (?<PerlStdStatement>
-            (?: (?>(?&PerlPod))   (?&PerlOWS) )?+
         (?>
             (?: (?>(?&PerlLabel)) (?&PerlOWS) )?+
-            (?: (?>(?&PerlPod))   (?&PerlOWS) )?+
+            (?&PerlPodSequence)?+
             (?>
                 (?&PerlKeyword)
             |
@@ -157,7 +163,7 @@ our $GRAMMAR = qr{
            (?: (?>(?&PerlNWS)) (?&PerlVersionNumber)
                (?! (?>(?&PerlOWS)) (?> (?&PerlInfixBinaryOperator) | (?&PerlComma) | \? ) )
            )?+
-           (?: (?>(?&PerlNWS)) (?&PerlPod) )?+
+           (?: (?>(?&PerlNWS)) (?&PerlPodSequence) )?+
            (?: (?>(?&PerlOWS)) (?&PerlExpression) )?+
        )
        (?>(?&PerlOWS)) (?> ; | (?= \} | \z ))
@@ -185,7 +191,6 @@ our $GRAMMAR = qr{
             (?>(?&PerlOWS))    (?&PerlLowPrecedenceNotExpression)  )*+
     )) # End of rule
 
-
     (?<PerlLowPrecedenceNotExpression>   (?<PerlStdLowPrecedenceNotExpression>
         (?: not \b (?&PerlOWS) )*+  (?&PerlCommaList)
     )) # End of rule
@@ -328,23 +333,23 @@ our $GRAMMAR = qr{
 
     (?<PerlControlBlock>   (?<PerlStdControlBlock>
         (?> # Conditionals...
-            (?> if | unless ) \b            (?>(?&PerlOWS))
+            (?> if | unless ) \b                 (?>(?&PerlOWS))
             (?>(?&PerlParenthesesList))          (?>(?&PerlOWS))
             (?>(?&PerlBlock))
 
             (?:
-                                            (?>(?&PerlOWS))
-                (?: (?>(?&PerlPod))            (?&PerlOWS)   )*+
-                    elsif \b                (?>(?&PerlOWS))
-                    (?>(?&PerlParenthesesList))  (?>(?&PerlOWS))
-                    (?&PerlBlock)
+                                                 (?>(?&PerlOWS))
+                (?&PerlPodSequence)?+
+                elsif \b                     (?>(?&PerlOWS))
+                (?>(?&PerlParenthesesList))  (?>(?&PerlOWS))
+                (?&PerlBlock)
             )*+
 
             (?:
-                                            (?>(?&PerlOWS))
-                (?: (?>(?&PerlPod))            (?&PerlOWS)  )*+
-                    else \b                 (?>(?&PerlOWS))
-                    (?&PerlBlock)
+                                             (?>(?&PerlOWS))
+                (?&PerlPodSequence)?+
+                else \b                      (?>(?&PerlOWS))
+                (?&PerlBlock)
             )?+
 
         |   # Loops...
@@ -427,10 +432,7 @@ our $GRAMMAR = qr{
     )) # End of rule
 
     (?<PerlBlock>   (?<PerlStdBlock>
-        \{                             (?>(?&PerlOWS))
-            (?: (?>(?&PerlStatement))     (?&PerlOWS)   )*+
-            (?: (?>(?&PerlPod))           (?&PerlOWS)   )?+
-        \}
+        \{  (?&PerlStatementSequence)?+  \}
     )) # End of rule
 
     (?<PerlCall>   (?<PerlStdCall>
@@ -1310,10 +1312,18 @@ our $GRAMMAR = qr{
         (?!)    # None, by default, but can be overridden in a composing regex
     )) # End of rule
 
+    (?<PerlPodSequence>   (?<PerlStdPodSequence>
+        (?>(?&PerlOWS))  (?: (?>(?&PerlPod))  (?&PerlOWS) )*+
+    )) # End of rule
+
     (?<PerlPod>   (?<PerlStdPod>
-        ^ = [^\W\d]\w*+          # A line starting with =<identifier>
-        .*?                      # Up to the first...
-        ^ = cut \b [^\n]*+ $     # ...line starting with =cut
+        ^ = [^\W\d]\w*+             # A line starting with =<identifier>
+        .*?                         # Up to the first...
+        (?>
+            ^ = cut \b [^\n]*+ $    # ...line starting with =cut
+        |                           # or
+            \z                      # ...EOF
+        )
     )) # End of rule
 
 
@@ -1818,7 +1828,7 @@ PPR::X - Pattern-based Perl Recognizer
 
 =head1 VERSION
 
-This document describes PPR::X version 0.000017
+This document describes PPR::X version 0.000018
 
 
 =head1 SYNOPSIS
@@ -2121,6 +2131,12 @@ Matches an entire valid Perl document, including leading or trailing
 whitespace, comments, and any final C<__DATA__> or C<__END__> section.
 
 
+=head3 C<< (?&PerlStatementSequence) >>
+
+Matches zero-or-more valid Perl statements, separated by optional
+POD sequences.
+
+
 =head3 C<< (?&PerlStatement) >>
 
 Matches a single valid Perl statement, including: control structures;
@@ -2689,8 +2705,14 @@ nor the same as a qualified identifier.
 
 =head3 C<< (?&PerlPod) >>
 
-Matches any contiguous set of POD directives,
-up to the first C<=cut>.
+Matches a single POD section containing any contiguous set of POD
+directives, up to the first C<=cut> or end-of-file.
+
+
+=head3 C<< (?&PerlPodSequence) >>
+
+Matches any sequence of POD sections,
+separated and /or surrounded by optional whitespace.
 
 
 =head3 C<< (?&PerlOWS) >>
